@@ -22,25 +22,10 @@
 #define GEDIT_APP_PRIVATE_H
 
 #include "gedit-app.h"
-#include "gedit-metadata-manager.h"
-#include "gedit-settings.h"
 #include "gedit-menu-extension.h"
 
 G_BEGIN_DECLS
 
-void		 _gedit_app_set_lockdown		(GeditApp          *app,
-							 GeditLockdownMask  lockdown);
-
-void		 _gedit_app_set_lockdown_bit		(GeditApp          *app,
-							 GeditLockdownMask  bit,
-							 gboolean           value);
-
-/* This one is a gedit-window function, but we declare it here to avoid
- * #include headaches since it needs the GeditLockdownMask declaration.
- */
-void		 _gedit_window_set_lockdown		(GeditWindow       *window,
-							 GeditLockdownMask  lockdown);
-
 /* global print config */
 GtkPageSetup		*_gedit_app_get_default_page_setup	(GeditApp         *app);
 void			 _gedit_app_set_default_page_setup	(GeditApp         *app,
@@ -49,10 +34,6 @@ GtkPrintSettings	*_gedit_app_get_default_print_settings	(GeditApp         *app);
 void			 _gedit_app_set_default_print_settings	(GeditApp         *app,
 								 GtkPrintSettings *settings);
 
-GeditMetadataManager	*_gedit_app_get_metadata_manager	(GeditApp  *app);
-
-GeditSettings		*_gedit_app_get_settings		(GeditApp  *app);
-
 GMenuModel		*_gedit_app_get_hamburger_menu		(GeditApp  *app);
 
 GMenuModel		*_gedit_app_get_notebook_menu		(GeditApp  *app);
