@@ -23,27 +23,21 @@
 /* TODO: add encoding property */
 
 #include "config.h"
-
 #include "gedit-file-chooser-dialog-gtk.h"
-
 #include <string.h>
-
 #include <glib/gi18n.h>
-
 #include "gedit-encodings-combo-box.h"
 #include "gedit-debug.h"
 #include "gedit-enum-types.h"
 #include "gedit-settings.h"
 #include "gedit-utils.h"
-
-#define ALL_FILES		_("All Files")
-#define ALL_TEXT_FILES		_("All Text Files")
+#include "gedit-file-chooser.h"
 
 struct _GeditFileChooserDialogGtk
 {
 	GtkFileChooserDialog parent_instance;
 
-	GSettings *filter_settings;
+	GeditFileChooser *gedit_file_chooser;
 
 	GtkWidget *option_menu;
 	GtkWidget *extra_widget;
@@ -184,13 +178,6 @@ chooser_get_file (GeditFileChooserDialog *dialog)
 	return gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
 }
 
-
-static GSList *
-chooser_get_files (GeditFileChooserDialog *dialog)
-{
-	return gtk_file_chooser_get_files (GTK_FILE_CHOOSER (dialog));
-}
-
 static void
 chooser_set_do_overwrite_confirmation (GeditFileChooserDialog *dialog,
                                        gboolean                overwrite_confirmation)
@@ -205,12 +192,6 @@ chooser_show (GeditFileChooserDialog *dialog)
 	gtk_widget_grab_focus (GTK_WIDGET (dialog));
 }
 
-static void
-chooser_hide (GeditFileChooserDialog *dialog)
-{
-	gtk_widget_hide (GTK_WIDGET (dialog));
-}
-
 static void
 chooser_destroy (GeditFileChooserDialog *dialog)
 {
@@ -230,26 +211,6 @@ chooser_get_window (GeditFileChooserDialog *dialog)
 	return GTK_WINDOW (dialog);
 }
 
-static void
-chooser_add_pattern_filter (GeditFileChooserDialog *dialog,
-                            const gchar            *name,
-                            const gchar            *pattern)
-{
-	GtkFileFilter *filter;
-
-	filter = gtk_file_filter_new ();
-
-	gtk_file_filter_set_name (filter, name);
-	gtk_file_filter_add_pattern (filter, pattern);
-
-	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
-
-	if (gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog)) == NULL)
-	{
-		gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
-	}
-}
-
 static void
 gedit_file_chooser_dialog_gtk_chooser_init (gpointer g_iface,
                                             gpointer iface_data)
@@ -266,22 +227,19 @@ gedit_file_chooser_dialog_gtk_chooser_init (gpointer g_iface,
 	iface->set_current_name = chooser_set_current_name;
 	iface->set_file = chooser_set_file;
 	iface->get_file = chooser_get_file;
-	iface->get_files = chooser_get_files;
 	iface->set_do_overwrite_confirmation = chooser_set_do_overwrite_confirmation;
 	iface->show = chooser_show;
-	iface->hide = chooser_hide;
 	iface->destroy = chooser_destroy;
 	iface->set_modal = chooser_set_modal;
 	iface->get_window = chooser_get_window;
-	iface->add_pattern_filter = chooser_add_pattern_filter;
 }
 
 static void
 gedit_file_chooser_dialog_gtk_dispose (GObject *object)
 {
-	GeditFileChooserDialogGtk *dialog_gtk = GEDIT_FILE_CHOOSER_DIALOG_GTK (object);
+	GeditFileChooserDialogGtk *dialog = GEDIT_FILE_CHOOSER_DIALOG_GTK (object);
 
-	g_clear_object (&dialog_gtk->filter_settings);
+	g_clear_object (&dialog->gedit_file_chooser);
 
 	G_OBJECT_CLASS (gedit_file_chooser_dialog_gtk_parent_class)->dispose (object);
 }
@@ -295,8 +253,7 @@ gedit_file_chooser_dialog_gtk_class_init (GeditFileChooserDialogGtkClass *klass)
 }
 
 static void
-create_option_menu (GeditFileChooserDialogGtk *dialog,
-                    GeditFileChooserFlags      flags)
+create_option_menu (GeditFileChooserDialogGtk *dialog)
 {
 	GtkWidget *label;
 	GtkWidget *menu;
@@ -305,7 +262,7 @@ create_option_menu (GeditFileChooserDialogGtk *dialog,
 	label = gtk_label_new_with_mnemonic (_("C_haracter Encoding:"));
 	gtk_widget_set_halign (label, GTK_ALIGN_START);
 
-	save_mode = (flags & GEDIT_FILE_CHOOSER_SAVE) != 0;
+	save_mode = TRUE;
 	menu = gedit_encodings_combo_box_new (save_mode);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), menu);
@@ -417,33 +374,13 @@ create_newline_combo (GeditFileChooserDialogGtk *dialog)
 }
 
 static void
-create_extra_widget (GeditFileChooserDialogGtk *dialog,
-                     GeditFileChooserFlags      flags)
+create_extra_widget (GeditFileChooserDialogGtk *dialog)
 {
-	gboolean needs_encoding;
-	gboolean needs_line_ending;
-
-	needs_encoding = (flags & GEDIT_FILE_CHOOSER_ENABLE_ENCODING) != 0;
-	needs_line_ending = (flags & GEDIT_FILE_CHOOSER_ENABLE_LINE_ENDING) != 0;
-
-	if (!needs_encoding && !needs_line_ending)
-	{
-		return;
-	}
-
 	dialog->extra_widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-
 	gtk_widget_show (dialog->extra_widget);
 
-	if (needs_encoding)
-	{
-		create_option_menu (dialog, flags);
-	}
-
-	if (needs_line_ending)
-	{
-		create_newline_combo (dialog);
-	}
+	create_option_menu (dialog);
+	create_newline_combo (dialog);
 
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dialog), dialog->extra_widget);
 }
@@ -478,202 +415,39 @@ action_changed (GeditFileChooserDialogGtk *dialog,
 	update_newline_visibility (dialog);
 }
 
-static void
-filter_changed (GeditFileChooserDialogGtk *dialog,
-		GParamSpec	       *pspec,
-		gpointer		data)
-{
-	GtkFileFilter *filter;
-
-	filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog));
-	if (filter != NULL)
-	{
-		/* Store ID of selected filter */
-		const gchar *name;
-		gint id = 0;
-
-		name = gtk_file_filter_get_name (filter);
-		g_return_if_fail (name != NULL);
-
-		if (strcmp (name, ALL_FILES) == 0)
-			id = 1;
-
-		gedit_debug_message (DEBUG_COMMANDS, "Active filter: %s (%d)", name, id);
-
-		g_settings_set_int (dialog->filter_settings,
-				    GEDIT_SETTINGS_ACTIVE_FILE_FILTER, id);
-	}
-}
-
-/* FIXME: use globs too - Paolo (Aug. 27, 2007) */
-static gboolean
-all_text_files_filter (const GtkFileFilterInfo *filter_info,
-		       gpointer                 data)
-{
-	static GSList *known_mime_types = NULL;
-	GSList *mime_types;
-
-	if (known_mime_types == NULL)
-	{
-		GtkSourceLanguageManager *lm;
-		const gchar * const *languages;
-
-		lm = gtk_source_language_manager_get_default ();
-		languages = gtk_source_language_manager_get_language_ids (lm);
-
-		while ((languages != NULL) && (*languages != NULL))
-		{
-			gchar **mime_types;
-			gint i;
-			GtkSourceLanguage *lang;
-
-			lang = gtk_source_language_manager_get_language (lm, *languages);
-			g_return_val_if_fail (GTK_SOURCE_IS_LANGUAGE (lang), FALSE);
-			++languages;
-
-			mime_types = gtk_source_language_get_mime_types (lang);
-			if (mime_types == NULL)
-				continue;
-
-			for (i = 0; mime_types[i] != NULL; i++)
-			{
-				if (!g_content_type_is_a (mime_types[i], "text/plain"))
-				{
-					gedit_debug_message (DEBUG_COMMANDS,
-							     "Mime-type %s is not related to text/plain",
-							     mime_types[i]);
-
-					known_mime_types = g_slist_prepend (known_mime_types,
-									    g_strdup (mime_types[i]));
-				}
-			}
-
-			g_strfreev (mime_types);
-		}
-
-		/* known_mime_types always has "text/plain" as first item" */
-		known_mime_types = g_slist_prepend (known_mime_types, g_strdup ("text/plain"));
-	}
-
-	/* known mime_types contains "text/plain" and then the list of mime-types unrelated to "text/plain"
-	 * that gedit recognizes */
-
-	if (filter_info->mime_type == NULL)
-		return FALSE;
-
-	/*
-	 * The filter is matching:
-	 * - the mime-types beginning with "text/"
-	 * - the mime-types inheriting from a known mime-type (note the text/plain is
-	 *   the first known mime-type)
-	 */
-
-	if (strncmp (filter_info->mime_type, "text/", 5) == 0)
-		return TRUE;
-
-	mime_types = known_mime_types;
-	while (mime_types != NULL)
-	{
-		if (g_content_type_is_a (filter_info->mime_type, (const gchar*)mime_types->data))
-			return TRUE;
-
-		mime_types = g_slist_next (mime_types);
-	}
-
-	return FALSE;
-}
-
 static void
 gedit_file_chooser_dialog_gtk_init (GeditFileChooserDialogGtk *dialog)
 {
-	dialog->filter_settings = g_settings_new ("org.gnome.gedit.state.file-filter");
 }
 
 GeditFileChooserDialog *
-gedit_file_chooser_dialog_gtk_create (const gchar             *title,
-			              GtkWindow               *parent,
-			              GeditFileChooserFlags    flags,
-			              const GtkSourceEncoding *encoding,
-				      const gchar             *cancel_label,
-				      GtkResponseType          cancel_response,
-				      const gchar             *accept_label,
-				      GtkResponseType          accept_response)
+gedit_file_chooser_dialog_gtk_create (const gchar *title,
+				      GtkWindow   *parent,
+				      const gchar *accept_label,
+				      const gchar *cancel_label)
 {
 	GeditFileChooserDialogGtk *result;
-	GtkFileFilter *filter;
-	gint active_filter;
-	GtkFileChooserAction action;
-	gboolean select_multiple;
-
-	if ((flags & GEDIT_FILE_CHOOSER_SAVE) != 0)
-	{
-		action = GTK_FILE_CHOOSER_ACTION_SAVE;
-		select_multiple = FALSE;
-	}
-	else
-	{
-		action = GTK_FILE_CHOOSER_ACTION_OPEN;
-		select_multiple = TRUE;
-	}
 
 	result = g_object_new (GEDIT_TYPE_FILE_CHOOSER_DIALOG_GTK,
 			       "title", title,
 			       "local-only", FALSE,
-			       "action", action,
-			       "select-multiple", select_multiple,
+			       "action", GTK_FILE_CHOOSER_ACTION_SAVE,
+			       "select-multiple", FALSE,
 			       NULL);
 
-	create_extra_widget (result, flags);
+	create_extra_widget (result);
 
 	g_signal_connect (result,
 			  "notify::action",
 			  G_CALLBACK (action_changed),
 			  NULL);
 
-	if (encoding != NULL)
-	{
-		gedit_encodings_combo_box_set_selected_encoding (GEDIT_ENCODINGS_COMBO_BOX (result->option_menu),
-		                                                 encoding);
-	}
-
-	active_filter = g_settings_get_int (result->filter_settings, GEDIT_SETTINGS_ACTIVE_FILE_FILTER);
-	gedit_debug_message (DEBUG_COMMANDS, "Active filter: %d", active_filter);
-
-	if ((flags & GEDIT_FILE_CHOOSER_ENABLE_DEFAULT_FILTERS) != 0)
-	{
-		/* "All Text Files" filter */
-		filter = gtk_file_filter_new ();
-		gtk_file_filter_set_name (filter, ALL_TEXT_FILES);
-		gtk_file_filter_add_custom (filter,
-					    GTK_FILE_FILTER_MIME_TYPE,
-					    all_text_files_filter,
-					    NULL,
-					    NULL);
-		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (result), filter);
-
-		if (active_filter != 1)
-		{
-			/* Use this filter if set by user and as default */
-			gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (result), filter);
-		}
-
-		/* "All Files" filter */
-		filter = gtk_file_filter_new ();
-		gtk_file_filter_set_name (filter, ALL_FILES);
-		gtk_file_filter_add_pattern (filter, "*");
-		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (result), filter);
-
-		if (active_filter == 1)
-		{
-			/* Use this filter if set by user */
-			gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (result), filter);
-		}
-
-		g_signal_connect (result,
-				  "notify::filter",
-				  G_CALLBACK (filter_changed),
-				  NULL);
-	}
+	/* FIXME: attention, there is a ref cycle here. This will be fixed when
+	 * GeditFileChooserSave will be created (and this class removed).
+	 */
+	result->gedit_file_chooser = _gedit_file_chooser_new ();
+	_gedit_file_chooser_set_gtk_file_chooser (result->gedit_file_chooser,
+						  GTK_FILE_CHOOSER (result));
 
 	if (parent != NULL)
 	{
@@ -681,9 +455,9 @@ gedit_file_chooser_dialog_gtk_create (const gchar             *title,
 		gtk_window_set_destroy_with_parent (GTK_WINDOW (result), TRUE);
 	}
 
-	gtk_dialog_add_button (GTK_DIALOG (result), cancel_label, cancel_response);
-	gtk_dialog_add_button (GTK_DIALOG (result), accept_label, accept_response);
-	gtk_dialog_set_default_response (GTK_DIALOG (result), accept_response);
+	gtk_dialog_add_button (GTK_DIALOG (result), cancel_label, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (result), accept_label, GTK_RESPONSE_ACCEPT);
+	gtk_dialog_set_default_response (GTK_DIALOG (result), GTK_RESPONSE_ACCEPT);
 
 	return GEDIT_FILE_CHOOSER_DIALOG (result);
 }
