@@ -23,7 +23,7 @@
 #include "gedit-print-job.h"
 
 #include <glib/gi18n.h>
-#include <gtksourceview/gtksource.h>
+#include <tepl/tepl.h>
 
 #include "gedit-debug.h"
 #include "gedit-print-preview.h"
@@ -534,7 +534,7 @@ create_compositor (GeditPrintJob *job)
 		gchar *left;
 
 		doc_name = gedit_document_get_uri_for_display (GEDIT_DOCUMENT (buf));
-		name_to_display = gedit_utils_str_middle_truncate (doc_name, 60);
+		name_to_display = tepl_utils_str_middle_truncate (doc_name, 60);
 
 		left = g_strdup_printf (_("File: %s"), name_to_display);
 
