@@ -33,16 +33,19 @@ G_BEGIN_DECLS
 G_DECLARE_FINAL_TYPE (GeditSettings, gedit_settings, GEDIT, SETTINGS, GObject)
 
 G_GNUC_INTERNAL
-GeditSettings *	_gedit_settings_get_singleton			(void);
+GeditSettings *	_gedit_settings_get_singleton				(void);
 
-void		gedit_settings_unref_singleton			(void);
+void		gedit_settings_unref_singleton				(void);
 
 G_GNUC_INTERNAL
-GSettings *	_gedit_settings_peek_editor_settings		(GeditSettings *self);
+GSettings *	_gedit_settings_peek_editor_settings			(GeditSettings *self);
 
-gchar *		gedit_settings_get_system_font			(GeditSettings *self);
+G_GNUC_INTERNAL
+GSettings *	_gedit_settings_peek_file_chooser_state_settings	(GeditSettings *self);
 
-GSList *	gedit_settings_get_candidate_encodings		(gboolean *default_candidates);
+gchar *		gedit_settings_get_system_font				(GeditSettings *self);
+
+GSList *	gedit_settings_get_candidate_encodings			(gboolean *default_candidates);
 
 /* key constants */
 #define GEDIT_SETTINGS_USE_DEFAULT_FONT			"use-default-font"
@@ -93,7 +96,10 @@ GSList *	gedit_settings_get_candidate_encodings		(gboolean *default_candidates);
 #define GEDIT_SETTINGS_SIDE_PANEL_ACTIVE_PAGE		"side-panel-active-page"
 #define GEDIT_SETTINGS_BOTTOM_PANEL_SIZE		"bottom-panel-size"
 #define GEDIT_SETTINGS_BOTTOM_PANEL_ACTIVE_PAGE		"bottom-panel-active-page"
+
+/* file chooser state keys */
 #define GEDIT_SETTINGS_ACTIVE_FILE_FILTER		"filter-id"
+#define GEDIT_SETTINGS_FILE_CHOOSER_OPEN_RECENT		"open-recent"
 
 G_END_DECLS
 
