@@ -34,6 +34,7 @@
 
 #include "gedit-dirs.h"
 #include "gedit-debug.h"
+#include "gedit-factory.h"
 #include "gedit-settings.h"
 
 #ifdef G_OS_WIN32
@@ -116,6 +117,7 @@ int
 main (int argc, char *argv[])
 {
 	GType type;
+	GeditFactory *factory;
 	GeditApp *app;
 	gint status;
 
@@ -132,12 +134,15 @@ main (int argc, char *argv[])
 	type = GEDIT_TYPE_APP;
 #endif
 
-	/* NOTE: we should not make any calls to the gedit api before the
-	 * private library is loaded */
+	/* NOTE: we should not make any calls to the gedit API before the
+	 * private library is loaded.
+	 */
 	gedit_dirs_init ();
 
 	setup_i18n ();
 	tepl_init ();
+	factory = gedit_factory_new ();
+	tepl_abstract_factory_set_singleton (TEPL_ABSTRACT_FACTORY (factory));
 
 	app = g_object_new (type,
 	                    "application-id", "org.gnome.gedit",
@@ -163,6 +168,7 @@ main (int argc, char *argv[])
 	}
 
 	tepl_finalize ();
+	gedit_dirs_shutdown ();
 
 #ifdef G_OS_WIN32
 	gedit_w32_unload_private_dll ();
